<template>
  <div>
    <el-dialog
      v-model="dialogVisible"
      :title="addOrEdit === 'edit' ? '编辑' : '新增' + '设备'"
      width="800"
      :title-style="{ textAlign: 'center' }"
      :close-on-click-modal="false"
      :before-close="handleClose"
    >
      <el-form
        ref="formRef"
        :model="formData"
        :rules="rules"
        label-width="auto"
      >
        <el-row :gutter="20">
          <el-col :span="11">
            <el-form-item label="设备编号" prop="equipmentName">
              <el-input
                v-model="formData.equipmentName"
                placeholder="请输入设备编号"
                :disabled="isViewMode"
                style="width: 100%"
              />
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item label="设备名称" prop="equipmentName">
              <el-input
                v-model="formData.equipmentName"
                placeholder="请输入设备名称"
                :disabled="isViewMode"
                style="width: 100%"
              />
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item label="数量" prop="quantity">
              <el-input
                v-model="formData.quantity"
                placeholder="请输入数量"
                :disabled="isViewMode"
                style="width: 100%"
              />
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item label="规格型号" prop="specification">
              <el-input
                v-model="formData.specification"
                placeholder="请输入规格型号"
                :disabled="isViewMode"
                style="width: 100%"
              />
            </el-form-item>
          </el-col>
          <!-- <el-col :span="11"> -->
            <!-- <el-form-item label="使用状态" prop="usageStatus">
              <el-select
                v-model="formData.usageStatus"
                placeholder="请选择使用状态"
                :disabled="isViewMode"
              >
                <el-option label="启用" value="1" />
                <el-option label="禁用" value="0" />
              </el-select>
            </el-form-item> -->
          <!-- </el-col> -->
          <el-col :span="11">
            <el-form-item label="使用部门" prop="usingDepartment">
              <el-input
                v-model="formData.usingDepartment"
                placeholder="请输入使用部门"
                :disabled="isViewMode"
                style="width: 100%"
              />
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item label="存放位置" prop="storageLocation">
              <el-input
                v-model="formData.storageLocation"
                placeholder="请输入存放位置"
                :disabled="isViewMode"
                style="width: 100%"
              />
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item label="采购价格" prop="purchasePrice">
              <el-input
                v-model="formData.purchasePrice"
                placeholder="请输入采购价格"
                :disabled="isViewMode"
                style="width: 100%"
              />
            </el-form-item>
          </el-col>
          <el-col :span="11">
            <el-form-item label="采购日期" prop="purchaseDate">
              <el-date-picker
                v-model="formData.purchaseDate"
                type="date"
                placeholder="请选择采购日期"
                size="default"
                :value-format="'YYYY-MM-DD'"
                style="width: 100%;"
                :disabled="isViewMode"
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-form-item class="dialog-footer">
          <el-button @click="cancelForm">取消</el-button>
          <el-button v-if="!isViewMode" type="primary" @click="submitForm">确定</el-button>
        </el-form-item>
      </el-form>
    </el-dialog>
  </div>
</template>

<script setup>
import { ref, watch, computed, reactive } from "vue";
import { addOrEditEquipment } from "@/api/equipment/management/index.js";

const props = defineProps({
  beforeClose: {
    type: Function,
    default: () => {},
  },
  form: {
    type: Object,
    default: () => ({}),
  },
  addOrEdit: {
    type: String,
    default: "add",
  },
  title: {
    type: String,
    default: "",
  },
});

const emit = defineEmits(["submit", "handleBeforeClose"]);

// 计算属性：统一控制是否禁用
const isViewMode = computed(() => props.addOrEdit === "viewRow");

// 表单引用和数据
const formRef = ref(null);
const formData = ref({});
const copyForm = defineModel("copyForm", {
  required: true,
  type: Object,
  default: () => ({}),
});

// 弹窗可见性
const dialogVisible = defineModel("managementFormDialog", {
  required: true,
  type: Boolean,
});

// 监听外部传入的表单数据变化，合并监听逻辑
watch(
  [() => props.form, () => props.addOrEdit],
  ([newForm, newAddOrEdit]) => {
    formData.value = { ...newForm };
  },
  { deep: true, immediate: true }
);
// 提交表单
const submitForm = async () => {
  if (!formRef.value) return;
  
  await formRef.value.validate(async (valid) => {
    if (!valid) return;
    
    try {
      const result = await addOrEditEquipment({ ...formData.value });
      const title = props.title.includes("新增") ? "新增" : "编辑";
      
      if (result.code === 200 && result.msg) {
        ElMessage.success(`${title}成功：${result.msg}`);
        emit("submit", { title, ...formData.value, result });
        closeDialog();
      } else {
        ElMessage.error(`${title}失败：${result.msg}`);
      }
    } catch (error) {
      console.error("提交失败:", error);
      ElMessage.error("提交失败，请重试");
    }
  });
};

// 关闭弹窗的统一方法
const closeDialog = () => {
  emit("update:managementFormDialog", false);
  formData.value = {};
};

// 取消表单
const cancelForm = () => {
  closeDialog();
};

// 重置表单
const resetForm = () => {
  if (!formRef.value) return;
  formData.value = JSON.parse(JSON.stringify(copyForm.value));
};

// 关闭弹窗
const handleClose = () => {
  emit("handleBeforeClose");
  closeDialog();
};
const rules = reactive({
  equipmentName: [
    { required: true, message: "请输入供货商名称", trigger: "blur" },
  ],
});
</script>
<style lang="scss" scoped>
.dialog-footer {
  display: flex;
  justify-content: flex-end;
  margin-top: 20px;
  flex-direction: column;
}

// 只为dialog头部加下划线
:deep(.el-dialog__header) {
  border-bottom: 1px solid #e8eaec;
  padding: 0 20px 10px 0;
  margin-bottom: 14px;
}
</style>
